#ifndef MENU_H
#define MENU_H


/**********************************************************************/
/* Exported functions                                                 */
/**********************************************************************/
gboolean create_game_menus();
void really_exit_cb (GtkWidget *, gpointer);
void exit_cb (GtkWidget *, gpointer);
/**********************************************************************/


#endif /* MENU_H */
